Struct bzip2::read::BzEncoder

source ·
pub struct BzEncoder<R> { /* private fields */ }
A compression stream which wraps an uncompressed stream of data. Compressed data will be read from the stream.

Implementations

Create a new compression stream which will compress at the given level to read compress output to the give output stream.

Acquires a reference to the underlying stream

Acquires a mutable reference to the underlying stream

Note that mutation of the stream may result in surprising results if this encoder is continued to be used.

Unwrap the underlying writer, finishing the compression stream.

Returns the number of bytes produced by the compressor (e.g. the number of bytes read from this stream)

Note that, due to buffering, this only bears any relation to total_in() when the compressor chooses to flush its data (unfortunately, this won’t happen in general at the end of the stream, because the compressor doesn’t know if there’s more data to come). At that point, total_out() / total_in() would be the compression ratio.

Returns the number of bytes consumed by the compressor (e.g. the number of bytes read from the underlying stream)